create_df_predictors.Rdcreate_df_predictors takes a vector of variable names and creates a dataframe of
create_df_predictors(names, n_vars = 3)The names of the dataframe to be expanded
Number of variables to be selected, e.g. expand.grid is called with 1:n_vars variables, and then results are combined and sorted to remove duplicates
an expanded data frame